@@ -1,4 +1,4 @@
-/* $Id: Httpd.java,v 1.4 1999/03/12 15:47:39 boyns Exp $ */
+/* $Id: Httpd.java,v 1.5 1999/05/27 06:09:59 boyns Exp $ */
 
 /*
  * Copyright (C) 1996-99 Mark R. Boyns <boyns@doit.org>
@@ -369,7 +369,7 @@ class Httpd extends HttpConnection
     {
 	Reply reply = new Reply(getInputStream());
 
-	reply.setHeaderField("Server", "Muffin/" + options.getString("muffin.version"));
+	reply.setHeaderField("Server", "Muffin/" + Main.getMuffinVersion());
 	reply.setHeaderField("Date", getDateString());
 	
 	if (request.getPath().startsWith("/images/"))
@@ -583,7 +583,7 @@ class Httpd extends HttpConnection
 
     static boolean sendme(Request request)
     {
-	return request.getHost().equalsIgnoreCase(options.getString("muffin.host"))
+	return request.getHost().equalsIgnoreCase(Main.getMuffinHost())
 	    && request.getPort() == options.getInteger("muffin.port");
     }
     
@@ -591,7 +591,7 @@ class Httpd extends HttpConnection
     {
 	StringBuffer buf = new StringBuffer();
 	buf.append("http://");
-	buf.append(options.getString("muffin.host"));
+	buf.append(Main.getMuffinHost());
 	buf.append(":");
 	buf.append(options.getString("muffin.port"));
 	return buf.toString();
@@ -600,9 +600,9 @@ class Httpd extends HttpConnection
     static String getGenerated()
     {
 	StringBuffer buf = new StringBuffer();
-	buf.append("<a href=\"" + options.getString("muffin.url") + "\">");
+	buf.append("<a href=\"" + Main.getMuffinUrl() + "\">");
 	buf.append("<i><img border=0 alt=\"\" src=\"" + Httpd.getLocation() + "/images/mufficon.jpg\">");
-	buf.append("Generated by Muffin " + options.getString("muffin.version") + "</a></i>");
+	buf.append("Generated by Muffin " + Main.getMuffinVersion() + "</a></i>");
 	buf.append("</a>\n");
 	return buf.toString();
     }
