@@ -1,4 +1,4 @@
-/* $Id: DecafFilter.java,v 1.4 1999/03/12 15:47:41 boyns Exp $ */
+/* $Id: DecafFilter.java,v 1.5 1999/05/29 17:34:23 boyns Exp $ */
 
 /*
  * Copyright (C) 1996-99 Mark R. Boyns <boyns@doit.org>
@@ -188,13 +188,21 @@ public class DecafFilter implements ContentFilter, ReplyFilter
 		    out.write(token);
 		}
 	    }
-	    
-	    out.flush();
-	    out.close();
 	}
-	catch (Exception e)
+	catch (IOException ioe)
 	{
-	    e.printStackTrace();
+	    ioe.printStackTrace();
+	}
+	finally
+	{
+	    try
+	    {
+		out.flush();
+		out.close();
+	    }
+	    catch (IOException ioe)
+	    {
+	    }
 	}
     }
 }
